function [X1,X1L,X2,X2L,freq]=get_spectra(x1,x2,L,win1,win2,nfft,fs)
%
% function to convert pair of speech frames (wideband analysis and
% narrowband analysis) to magnitude and log magnitude representations;  The
% spectra analyses only plot from o to fs/4 for higher spectral resolution.
%
% Inputs:
%   x1: wideband analysis frame around selected speech sample
%   x2: narrowband analysis frame around selected speech sample
%   L: analysis frame window durations in samples; L(1) is wideband
%       analysis duration, L(2) is narrowband analysis duration
%   win1: analysis window for wideband analysis frame
%   win2: analysis window for narrowband analysis frame
%   nfft: size of fft for spectral analysis
%   fs: sampling rate of speech signal
%
% Outputs:
%   X1: magnitude spectrum of wideband analysis frame
%   X1L: log magnitude spectrum of wideband analysis frame
%   X2: magnitude spectrum of narrowband analysis frame
%   X2L: log magnitude spectrum of narrowband analysis frame
%   freq: frequency scale for spectral plots, from 0 to fs/4

% create frequency scale for spectral plots, from 0 to fs/4
    freq=0:fs/nfft:fs/2;
    
% window wideband analysis frame and perform spectral analysis to give
% magnitude spectrum for wideband analysis
    x1e=x1.*win1;
    X1=abs(fft(x1e,nfft));
    X1L=20*log10(X1);
    
% window narrowband analysis frame and perform spectral analysis to give
% magnitude spectrum for narrowband analysis
    x2e=x2.*win2;
    X2=abs(fft(x2e,nfft));
    X2L=20*log10(X2);
end