function [L,win1,win2]=setup_spectra(LWB,LNB,fs,wtype)
%
% function to create frame durations for wideband and narrowband analyses;
% function also creates windows from wtype (1:Hamming, 2:rectangular) for
% both wideband and narrowband analysis
%
% Inputs:
%   LWB: wideband frame duration in msec
%   LNB: narrowband frame duration in msec
%   wtype: window type; 1:Hamming, 2:rectangular
%
% Outputs:
%   L: 2-element array with L(1)=LWB and L(2)=LNB;  both in samples
%   win1: window function for wideband analysis
%   win2: window function for narrowband analysis

% create wideband and narrowband window durations in samples
    L(1)=round(LWB*fs/1000);
    L(2)=round(LNB*fs/1000);
    
% create window 1 for wideband analysis
    if (wtype == 1)
        win1=hamming(L(1))';
        win2=hamming(L(2))';
    else
        win1=ones(1,L(1));
        win2=ones(1,L(2));
    end
end